BytesReturn class final

Inheritance
Implemented types
Available extensions

Constructors

BytesReturn()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
error ↔ Pointer<Utf8>
getter/setter pair
errorMessage → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
message ↔ Pointer<Void>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toUint8List() → Uint8List

Operators

operator ==(Object other) → bool
The equality operator.
inherited