Curve class

Constructors

Curve.fromValue(int value)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

containsValue(int value) → bool

Constants

BRAINPOOLP256 → const Curve
BRAINPOOLP384 → const Curve
BRAINPOOLP512 → const Curve
CURVE448 → const Curve
CURVE25519 → const Curve
maxValue → const int
minValue → const int
P256 → const Curve
P384 → const Curve
P521 → const Curve
reader → const Reader<Curve>
SECP256K1 → const Curve
values → const Map<int, Curve>