EncryptSymmetricRequestObjectBuilder class

Inheritance
  • Object
  • ObjectBuilder
  • EncryptSymmetricRequestObjectBuilder

Constructors

EncryptSymmetricRequestObjectBuilder({String? message, String? passphrase, KeyOptionsObjectBuilder? options, FileHintsObjectBuilder? fileHints})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

finish(Builder fbBuilder) → int
Finish building, and store into the fbBuilder.
override
getOrCreateOffset(Builder fbBuilder) → int
Can be used to write the data represented by this builder to the Builder and reuse the offset created in multiple tables.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes([String? fileIdentifier]) → Uint8List
Convenience method to serialize to byte list.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited