PublicKeyMetadataBuilder class

Constructors

PublicKeyMetadataBuilder(Builder fbBuilder)

Properties

fbBuilder → Builder
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAlgorithmOffset(int? offset) → int
addCanEncrypt(bool? canEncrypt) → int
addCanSign(bool? canSign) → int
addCreationTimeOffset(int? offset) → int
addFingerprintOffset(int? offset) → int
addIdentitiesOffset(int? offset) → int
addIsSubKey(bool? isSubKey) → int
addKeyIdNumericOffset(int? offset) → int
addKeyIdOffset(int? offset) → int
addKeyIdShortOffset(int? offset) → int
addSubKeysOffset(int? offset) → int
begin() → void
finish() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited