OpenpgpPlugin class

Constructors

OpenpgpPlugin()

Properties

completers ↔ Map<String, Completer<Uint8List>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worker ↔ Worker
getter/setter pair

Methods

bridgeCall(String name, Uint8List? request) → Future<Uint8List>
handleMethodCall(MethodCall call) → Future
listen() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void